@@ -183,7 +183,7 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.1)
+             time.sleep(0.05)
              self.port.flushOutput()
              self.port.flushInput()
              for c in cmd:
@@ -268,11 +268,6 @@ class OBDPort:
          sensor = obd_sensors.SENSORS[sensor_index]
          r = self.get_sensor_value(sensor)
 
-         log1="Sensor: " + str(sensor.name)
-         print log1
-         log2="echo '"+log1+"' >> /home/user/MyDocs/pyobd.log"
-         os.popen(log2)
-
          return (sensor.name,r, sensor.unit)
 
      def sensor_names(self):
