@@ -37,10 +37,16 @@ def hex_to_int(str):
     return i
 
 def maf(code):
-    code = hex_to_int(code)
+    #a = hex_to_int(code)
+    #print a
+
+    numA = hex_to_int(code[:2]) #A byte
+    numB = hex_to_int(code[2:4]) #B byte
+    code=(numA*256+numB)/100.0
     lb=code * 0.002205
     return str(code)+"#"+str(lb)[:6]
 
+
 def throttle_pos(code):
     code = hex_to_int(code)
     return code * 100.0 / 255.0
