@@ -208,8 +208,9 @@ class MyApp(wx.App):
         
 
         def run(self):
-            global btname, maxbar
+            global btname, maxbar, maxmaf
             maxbar=0
+            maxmaf=0
 
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
@@ -259,7 +260,7 @@ class MyApp(wx.App):
 
                   log2="echo  >> /home/user/MyDocs/pyobd.log"
                   os.popen(log2)
-                  log1="time: "+str(datetime.datetime.now())
+                  log1="time : "+str(datetime.datetime.now())
                   log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
                   os.popen(log2)
                   log2="echo  >> /home/user/MyDocs/pyobd.log"
@@ -271,7 +272,8 @@ class MyApp(wx.App):
                           s = self.port.sensor(i)
                           wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1], s[2])]))
 #log
-                          log1="Value : "+str(s[1])+" "+str(s[2])
+                          log1=str(s[0])+" : "+str(s[1])+" "+str(s[2])
+                          #print s
                           print log1
                           log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
                           os.popen(log2)
@@ -361,11 +363,27 @@ class MyApp(wx.App):
 				n=0
 				while n<(l-1):
 					if str(text[n]) == '#' :
-						text=text[0:n]
+						text="MAP"+text[0:n]
 						break
 					n=n+1
 				wx.PostEvent(self._notify_window, DialEvent1(text))
-			wx.Yield()                   
+
+				wx.Yield()                   
+
+			speedsensor=16
+
+			if self.active[speedsensor]:
+				s = self.port.sensor(speedsensor)
+				text=str(s[1])
+				l=len(text)
+				n=0
+				while n<(l-1):
+					if str(text[n]) == '#' :
+						text="MAF"+text[0:n]
+						break
+					n=n+1
+				wx.PostEvent(self._notify_window, DialEvent1(text))
+				wx.Yield()                   
 
 
                 else:
@@ -659,7 +677,8 @@ class MyApp(wx.App):
                                           SM.SM_DRAW_PARTIAL_SECTORS |
                                           SM.SM_DRAW_MIDDLE_TEXT |
                                           SM.SM_DRAW_TITLE_TEXT |
-                                          SM.SM_DRAW_SUB_TEXT
+                                          SM.SM_DRAW_SUB_TEXT |
+                                          SM.SM_DRAW_SUB2_TEXT
                                           )
  
         # We Want To Simulate A Car Gas-Control
@@ -685,8 +704,9 @@ class MyApp(wx.App):
 
         self.SpeedWindow3.SetHandColour(wx.Colour(255, 255, 0))
 
-        self.SpeedWindow3.SetTitleText("MAP\n(intake manifold absolute pressure)") #
-        self.SpeedWindow3.SetSubText("Max: ") #
+        self.SpeedWindow3.SetTitleText("MAP\n(intake manifold absolute pressure)\n\n\n\nMAF (Air Flow Rate) g/s#lb/s") #
+        self.SpeedWindow3.SetSubText("Max: -") #
+        self.SpeedWindow3.SetSub2Text("Cur: -\nMax: -")
 
         # Draw The Icon In The Center Of SpeedMeter        
         #self.SpeedWindow3.SetMiddleIcon(icon)        
@@ -930,7 +950,7 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """ pyobd-0.9.2-20
+        Text = """ pyobd-0.9.2-21
 
 Adapted to n900 by m750 at maemo.org
 """
@@ -1034,20 +1054,33 @@ later version.
 		self.SpeedWindow5.SetSpeedValue(d2)
 
     def OnDial1(self,event):
-	global maxbar
+	global maxbar, maxmaf
 	data=event.data
-	#print data
-	d1=int(data)/100.0
-	d2=4-d1
-	#print d1
-	#print d2
-	self.SpeedWindow3.SetSpeedValue(d2)
-	wx.Yield()
-	if d1>maxbar:
-		maxbar=d1
-		self.SpeedWindow3.SetSubText("Max: "+str(d1))
+
+	d1=data[:3]
+	d2=data[3:]
+
+	if d1=="MAP":
+		d2=int(d2)/100.0
+		if d2>maxbar:
+			maxbar=d2
+			self.SpeedWindow3.SetSubText("Max: "+str(d2))
+		wx.Yield()
+		if d2>4:
+			d2=4
+		d2=4-d2
+		self.SpeedWindow3.SetSpeedValue(d2)
+
+	elif d1=="MAF":
+		d2=float(d2)
+		if d2>maxmaf:
+			maxmaf=d2
+		d2=str(d2)+"#"+str(d2*0.0022)[:6]
+		text="Cur: "+str(d2)+"\nMax: "+str(maxmaf)+"#"+str(maxmaf*0.0022)[:6]
+		self.SpeedWindow3.SetSub2Text(text)
 	wx.Yield()
 
+
     def OnDisconnect(self,event): #disconnect connection to ECU
         global btaddr, seriale, node, manager, bus, adapter, target_address , service, path
         print "stop"
